%define major           0.8
%define libname         %mklibname brlapi %{major}
%define develname       %mklibname brlapi -d

# "fix" underlinking:
%define _disable_ld_no_undefined 1

%ifarch %arm %mips
%define build_java 0
%else
%define build_java 1
%endif

Name:           brltty
Version:        6.1
Release:        %mkrel 5
Summary:        Braille display driver for Linux/Unix
License:	LGPLv2+
Group:          Accessibility
URL:		http://brltty.app/
Source0:	http://brltty.app/archive/%{name}-%{version}.tar.xz
Source1: brltty.service
# Fedora patch
Patch1: brltty-6.0-loadLibrary.patch
# libspeechd.h moved in latest speech-dispatch (NOT sent upstream)
Patch2: brltty-5.0-libspeechd.patch
Patch20:         brltty-5.3.1-python-link.patch
BuildRequires:	systemd-devel
BuildRequires:  bison
BuildRequires:  festival-devel
BuildRequires:  gpm-devel
BuildRequires:  libbraille-devel
BuildRequires:  ocaml-compiler
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  python3dist(cython)
BuildRequires:  python3dist(setuptools)
BuildRequires:  speech_tools-devel
BuildRequires:  subversion
BuildRequires:  libespeak-devel

%description
BRLTTY is a background process (daemon) which provides
access to the Linux/Unix console (when in text mode)
for a blind person using a refreshable braille display.
It drives the braille display and provides complete
screen review functionality.
Some speech capability has also been incorporated.

%package -n %{libname}
Summary:    API for brltty
Group:      System/Libraries
License:    LGPLv2+

%description -n %{libname}
This package provides the run-time support for the Application
Programming Interface to BRLTTY.

Install this package if you have an application which directly accesses
a refreshable braille display.

%package -n %{develname}
Group:      Development/C
License:    LGPLv2+
Summary:    Headers, static archive, and documentation for BrlAPI
Provides:   brlapi-devel = %{version}-%{release}
Requires:   %{libname} = %{version}-%{release}

%description -n %{develname}
This package provides the header files, static archive, shared object
linker reference, and reference documentation for BrlAPI (the
Application Programming Interface to BRLTTY).  It enables the
implementation of applications which take direct advantage of a
refreshable braille display in order to present information in ways
which are more appropriate for blind users and/or to provide user
interfaces which are more specifically attuned to their needs.

Install this package if you are developing or maintaining an application
which directly accesses a refreshable braille display.

%package -n python3-brlapi
Summary:    Python 3 bindings for BrlAPI
Group:      Development/Python
%{?python_provide:%python_provide python3-brlapi}

%description -n python3-brlapi
This package provides the Python 3 binding for BrlAPI.

%if %{build_java}
%package -n brlapi-java
Group:      Development/Java
BuildRequires:  java-devel
Summary: Java binding for BrlAPI

%description -n brlapi-java
This package provides the Java binding for BrlAPI.
%endif

%package -n ocaml-brlapi
Summary:    Ocaml bindings for BrlAPI
Group:      Development/OCaml
Obsoletes:  brlapi-ocaml < %{version}-%{release}

%description -n ocaml-brlapi
This package provides the OCaml binding for BrlAPI.

%package -n ocaml-brlapi-devel
Summary:    Development files for ocaml-brlapi
Group:      Development/OCaml
Requires:   ocaml-brlapi = %{version}-%{release}
Requires:   brlapi-devel

%description  -n ocaml-brlapi-devel
The ocaml-brlapi-devel package contains libraries and signature files for
developing applications that use ocaml-brlapi.

%package dracut
Summary: brltty module for Dracut
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: dracut
%description dracut
This package provides brltty module for Dracut.

%prep
%setup -q
%autopatch -p1

%build
autoconf -v -f
# Add the openjdk include directories to CPPFLAGS
for i in -I/usr/lib/jvm/java/include{,/linux}; do
      java_inc="$java_inc $i"
done
export CPPFLAGS="$java_inc"

export LDFLAGS="%{?build_ldflags}"
export CFLAGS="%{optflags} -fno-strict-aliasing $LDFLAGS"
export CXXFLAGS="%{optflags} -fno-strict-aliasing $LDFLAGS"
export PYTHON=%{__python3}
%configure  CPPFLAGS="$java_inc" \
                --with-install-root="%{buildroot}" \
                --disable-relocatable-install \
                --disable-tcl-bindings \
                --disable-stripping

# Parallel build seems broken, thus disabling it
make

%install
install -d -m 755 %{buildroot}%{_libdir}/ocaml/stublibs
# just to avoid an installation error
touch %{buildroot}%{_libdir}/ocaml/ld.conf
make install
install -m644 Documents/%{name}.conf -D %{buildroot}%{_sysconfdir}/%{name}.conf
install -m644 Documents/%{name}.1 -D %{buildroot}%{_mandir}/man1/%{name}.1
rm -f %{buildroot}%{_libdir}/ocaml/ld.conf

%if %{build_java}
# Missing java library
install -d -m 755 %{buildroot}%{_libdir}/java/
cp Bindings/Java/*.so '%{buildroot}%{_libdir}/java/'
# for some reason 64-bit install libbrlapi_java.so in both lib and lib64
# So we'll remove it
%ifarch x86_64 aarch64
rm -rf %{buildroot}%{_prefix}/lib/java
%endif
%endif

# Missing ocaml library
cp Bindings/OCaml/*.a '%{buildroot}%{_libdir}/ocaml/brlapi/'
%ifnarch %mips
cp Bindings/OCaml/*.cmx '%{buildroot}%{_libdir}/ocaml/brlapi/'
%endif

install -Dpm 644 %{SOURCE1} $RPM_BUILD_ROOT%{_unitdir}/brltty.service

directory="doc"
mkdir -p "${directory}"
for file in `find . \( -path "./${directory}" -o -path ./Documents \) -prune -o \( -name 'README*' -o -name '*.patch' -o -name '*.txt' -o -name '*
.html' -o -name '*.sgml' -o \( -path "./Bootdisks/*" -type f -perm +ugo=x \) \) -print`
do
   mkdir -p "${directory}/${file%/*}"
   cp -rp "${file}" "${directory}/${file}"
done

# handle locales
%find_lang %{name}
cp -p %{name}.lang ../

#Use python 3 for latex-access, BZ 1465657.
/usr/bin/2to3 -wn ${RPM_BUILD_ROOT}/etc/brltty/Contraction/latex-access.ctb
sed -i 's|/usr/bin/python|%{__python3}|g' ${RPM_BUILD_ROOT}/etc/brltty/Contraction/latex-access.ctb

# install dracut module
make install-dracut

%post
%systemd_post brltty.service

%preun
%systemd_preun brltty.service

%postun
%systemd_postun_with_restart brltty.service

%files -f %{name}.lang
%doc README Documents/ChangeLog Documents/TODO
%config(noreplace) %{_sysconfdir}/%{name}.conf
%{_unitdir}/brltty.service
%{_bindir}/*
%{_sysconfdir}/%{name}
%{_sysconfdir}/X11/Xsession.d/90xbrlapi
%{_libdir}/%{name}
%{_mandir}/man1/*
%{_datadir}/gdm/greeter/autostart/xbrlapi.desktop
%{_datadir}/polkit-1/actions/org.a11y.brlapi.policy
#{_datadir}/metainfo/org.a11y.brltty.metainfo.xml

%files -n %{libname}
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%doc Documents/BrlAPIref
%{_libdir}/*.so
%{_libdir}/*.a
%{_includedir}/brlapi.h
%{_includedir}/brlapi_*.h
%{_includedir}/brltty
%{_mandir}/man3/*

%if %{build_java}
%files -n brlapi-java
%{_libdir}/java/libbrlapi_java.so
%{_datadir}/java/brlapi.jar
%endif

%files -n python3-brlapi
%{python3_sitearch}/*

%files -n ocaml-brlapi
%dir %{_libdir}/ocaml/brlapi
%{_libdir}/ocaml/brlapi/META
%{_libdir}/ocaml/brlapi/*.cma
%{_libdir}/ocaml/brlapi/*.cmi
%{_libdir}/ocaml/stublibs/*.so*

%files -n ocaml-brlapi-devel
%{_libdir}/ocaml/brlapi/*.a
%ifnarch %mips
%{_libdir}/ocaml/brlapi/*.cmxa
%{_libdir}/ocaml/brlapi/*.cmx
%endif
%{_libdir}/ocaml/brlapi/*.mli

%files dracut
%{_prefix}/lib/dracut/modules.d/99brltty/
%dir %{_sysconfdir}/brltty/Initramfs
%config(noreplace) %verify(not size md5 mtime) %{_sysconfdir}/brltty/Initramfs/dracut.conf
%config(noreplace) %verify(not size md5 mtime) %{_sysconfdir}/brltty/Initramfs/cmdline


%changelog
* Sat Dec 05 2020 tv <tv> 6.1-5.mga8
+ Revision: 1653101
- Rebuild for new libicu

* Tue Sep 29 2020 tv <tv> 6.1-4.mga8
+ Revision: 1631102
- use %%find_lang
- BR systemd
- Add systemd unit file (rhbz#916628)
- fix java deps

* Fri Aug 21 2020 pterjan <pterjan> 6.1-3.mga8
+ Revision: 1617693
- Fix version in -dracut dependency on the main package
+ umeabot <umeabot>
- Rebuild for new ocaml deps generator
+ tv <tv>
- add dracut module in its own subpkg

* Fri Apr 10 2020 tv <tv> 6.1-1.mga8
+ Revision: 1566151
- 6.1 (api: 0.6 -> 0.8)
- adjust license
- add support for eSpeak
- better way to pass our flags
- simplify binding descriptions

* Thu Feb 27 2020 umeabot <umeabot> 5.5-11.mga8
+ Revision: 1551117
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 5.5-10.mga8
+ Revision: 1544307
- Mageia 8 Mass Rebuild

* Sat Jan 25 2020 tv <tv> 5.5-9.mga8
+ Revision: 1482774
- fix ambiguous python shebang
- rebuild for ocaml-4.10
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Sep 09 2019 wally <wally> 5.5-8.mga8
+ Revision: 1438953
- rebuild for python3.8

* Mon Jan 07 2019 shlomif <shlomif> 5.5-7.mga7
+ Revision: 1351495
- Rebuild for python3 3.7

* Thu Oct 25 2018 daviddavid <daviddavid> 5.5-6.mga7
+ Revision: 1325232
- rebuild for new ocaml 4.07.1

* Mon Oct 22 2018 pterjan <pterjan> 5.5-5.mga7
+ Revision: 1323710
- Rebuild for ocaml 4.07

* Sat Sep 22 2018 daviddavid <daviddavid> 5.5-4.mga7
+ Revision: 1295837
- add patch to fix build with new glibc
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Mon Jun 18 2018 wally <wally> 5.5-3.mga7
+ Revision: 1237877
- fix build on aarch64

* Sun Nov 26 2017 tv <tv> 5.5-2.mga7
+ Revision: 1179443
- rebuild for new ocaml

* Sat Sep 02 2017 guillomovitch <guillomovitch> 5.5-1.mga7
+ Revision: 1150677
- new version 5.5

* Sat Aug 05 2017 pterjan <pterjan> 5.3.1-4.mga7
+ Revision: 1135190
- Rebuild for python 3.6

* Sun Sep 25 2016 pterjan <pterjan> 5.3.1-3.mga6
+ Revision: 1056200
- Rebuild for fix in ocaml

* Thu Apr 28 2016 tv <tv> 5.3.1-2.mga6
+ Revision: 1007133
+ rebuild (emptylog)

* Fri Apr 15 2016 shlomif <shlomif> 5.3.1-1.mga6
+ Revision: 1002674
- New version 5.3.1

* Wed Feb 03 2016 pterjan <pterjan> 4.5-19.mga6
+ Revision: 934176
- Rebuild for new ocaml

* Sun Nov 01 2015 tv <tv> 4.5-18.mga6
+ Revision: 896992
- parallel build seems broken, thus disabling it

* Wed Oct 07 2015 ovitters <ovitters> 4.5-17.mga6
+ Revision: 887036
- rebuild for new python3

* Fri Oct 31 2014 pterjan <pterjan> 4.5-16.mga5
+ Revision: 794863
- Drop no longer needed BuildRequires on java-rpmbuild

* Wed Oct 15 2014 umeabot <umeabot> 4.5-15.mga5
+ Revision: 744038
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 4.5-14.mga5
+ Revision: 725985
- rebuild for missing pythoneggs deps

* Thu Sep 18 2014 umeabot <umeabot> 4.5-13.mga5
+ Revision: 693516
- Rebuild to fix library dependencies
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 4.5-11.mga5
+ Revision: 629667
- Rebuild for new Python

* Sat May 31 2014 pterjan <pterjan> 4.5-10.mga5
+ Revision: 629528
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 4.5-9.mga4
+ Revision: 541432
- Mageia 4 Mass Rebuild
+ pterjan <pterjan>
- Rebuild to add different pythonegg provides for python 2 and 3

* Sat Oct 12 2013 solbu <solbu> 4.5-7.mga4
+ Revision: 495898
- Fix BuildRequires
- Rebuild for ncurses/tinfo split
- Rebuild for ncurses/tinfo split

* Sun Jun 30 2013 fwang <fwang> 4.5-5.mga4
+ Revision: 448533
- only build python3 flavour

* Sun Jun 30 2013 fwang <fwang> 4.5-4.mga4
+ Revision: 448525
- import sysconfig
- fix python linking
- update py3dir
- do not use build dir
- add python3 flavour

* Sat Jun 08 2013 fwang <fwang> 4.5-3.mga4
+ Revision: 440443
- we are now link /lib to /usr/lib

* Fri May 31 2013 solbu <solbu> 4.5-2.mga4
+ Revision: 433647
- Fix BuildRequires
- Drop P2, unneeded with correct BuildRequires

* Thu May 30 2013 pterjan <pterjan> 4.5-1.mga4
+ Revision: 433490
- Fix build of python binding
- Use apply_patches
- Update major
+ solbu <solbu>
- New version

* Sat Mar 09 2013 rtp <rtp> 4.4-3.mga3
+ Revision: 401984
- fix build without ocaml opt
- Disable java on arm/mips.

* Fri Jan 11 2013 umeabot <umeabot> 4.4-2.mga3
+ Revision: 347195
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 30 2012 malo <malo> 4.4-1.mga3
+ Revision: 301055
- new version 4.4
- add patch from mdv (pok) to fix java build
- add autoconf to prep (mdv)
- update RPM groups
+ fwang <fwang>
- new version 4.4

* Tue Jun 05 2012 solbu <solbu> 4.3-1.mga3
+ Revision: 255999
- brltty doesn't support concurent builds
- Fix build error
- Spec cleanup
- New version
- Drop patches 5 and 7. merged upstream or not needed.

* Sun Dec 04 2011 malo <malo> 4.2-5.mga2
+ Revision: 176172
- adding missing Requires brlapi-devel for ocaml-brlapi

* Sat Dec 03 2011 malo <malo> 4.2-4.mga2
+ Revision: 175569
- spec cleanup
- renamed brlapi-ocaml to ocaml-brlapi, per policy
- included missing files for the ocaml api
+ fwang <fwang>
- cleanup br

* Sat May 07 2011 tv <tv> 4.2-2.mga1
+ Revision: 95829
- readd back silently deleted "useless macro definition" that
  broke brltty

* Thu May 05 2011 misc <misc> 4.2-1.mga1
+ Revision: 95051
- fix previous patch
- fix build, missing include
- update to 4.2
- remove patch0, uneeded ( or so do I think )
- rediff patch5, ( // make )

* Tue Feb 22 2011 ahmad <ahmad> 4.1-6.mga1
+ Revision: 55873
- rebuild to make all pythonegg requires/provides lowercase
- rebuild against festival without esound support

* Tue Jan 25 2011 misc <misc> 4.1-5.mga1
+ Revision: 38154
- add comments
- remove old %%post
- imported package brltty

